@@ -1,4 +1,4 @@
-# $Id: Result.pm 1551 2006-11-07 02:03:05Z claco $
+# $Id: Result.pm 1593 2006-11-15 02:10:36Z claco $
 ## no critic (RequireFinalReturn)
 package Handel::Storage::Result;
 use strict;
@@ -21,6 +21,15 @@ sub discard_changes {
     throw Handel::Exception::Virtual;
 };
 
+sub has_column {
+    my ($self, $column) = @_;
+    if ($self->can($column)) {
+        return 1;
+    } else {
+        return;
+    };
+};
+
 sub update {
     throw Handel::Exception::Virtual;
 };
@@ -245,6 +254,16 @@ Discards all changes made since the last successful update.
 
 B<This method must be implemented in custom subclasses.>
 
+=head2 has_column
+
+=over
+
+=item Arguments: $column
+
+=back
+
+Returns true if the column exists in the current result object.
+
 =head2 items
 
 Same as L</search_items>.
