@@ -1,4 +1,4 @@
-# $Id: Second.pm 707 2005-08-10 01:42:14Z claco $
+# $Id: Second.pm 1487 2006-10-19 02:56:29Z claco $
 package Handel::OtherTestPlugins::Second;
 use strict;
 use warnings;
@@ -9,7 +9,7 @@ sub register {
     my ($self, $ctx) = @_;
 
     $self->{'register_called'}++;
-    $ctx->add_handler(CHECKOUT_PHASE_INITIALIZE, \&handler);
+    $ctx->add_handler(CHECKOUT_PHASE_INITIALIZE, \&handler, 2);
 };
 
 sub init {
@@ -35,7 +35,7 @@ sub handler {
 
     $self->{'handler_called'}++;
 
-    return CHECKOUT_HANDLER_OK;
+    return CHECKOUT_HANDLER_DECLINE;
 };
 
-1;
\ No newline at end of file
+1;
