@@ -1,8 +1,8 @@
-# $Id: CartOnly.pm 1300 2006-07-08 01:12:16Z claco $
+# $Id: CartOnly.pm 1409 2006-09-09 21:16:54Z claco $
 package Handel::Subclassing::CartOnly;
 use strict;
 use warnings;
-use base 'Handel::Cart';
+use base qw/Handel::Cart/;
 
 __PACKAGE__->storage->add_columns('custom');
 __PACKAGE__->create_accessors;
